==> emodpy_tbhiv-1.0.5.dev0-py3-none-any.whl: tests/test_tbhivtreat.py <==
#!/usr/bin/env python
import unittest
import copy
import json
import os
import manifest
from intervention_test import TestIntervention

import emodpy_tbhiv.interventions.tbhiv_treat as treat
import emod_api.campaign as camp


class Testtbhivtreat(TestIntervention):
    """
    Test TBHIVConfigurableTBdrug intervention
    """
    def test_default(self):
        super().trigger_treatment_list_with_drug_name_test(treat.TBHIVDrugTreatment,
                                                           "TBHIVdrug", 'TBHIVConfigurableTBdrug',
                                                           'camp_tbhivtreat.json', is_multi=True)

    def test_all(self, intervention_class_name='TBHIVConfigurableTBdrug'):
        camp.set_schema( self.schema )
        treatment_list = ['infected']
        drug_name = 'TBHIVConfigurableTBdrug'
        latent_multiplier=0.9
        active_multiplier=0.9
        start_day=5
        duration=50
        property_restrictions_list = ["Risk: HIGH"]
        nodeIDs = []
        black_period = 10
        black_trigger = 'Blackout'
        event_name = 'TB Diagnosis Active Simple'
        intervention_class = "TBHIVDrugTreatment"
        event = treat.TBHIVDrugTreatment(camp, treatment_list, drug_name, latent_multiplier,
                                         active_multiplier, start_day, duration,
                                         property_restrictions_list, nodeIDs, black_period,
                                         black_trigger, event_name)

        camp.campaign_dict["Events"] = []
        camp.add(event)
        camp_filename = os.path.join(self.output, "camp_treat.json")
        manifest.delete_existing_file(camp_filename)
        camp.save(camp_filename)
        self.assertTrue(os.path.isfile(camp_filename))

        with open(camp_filename, 'r') as file:
            camp_file = json.load(file)
        ecc = camp_file["Events"][0]["Event_Coordinator_Config"]
        ic = ecc["Intervention_Config"]

        self.assertListEqual(ic["Property_Restrictions"], [property_restrictions.replace(" ", "") for
                                                           property_restrictions in property_restrictions_list])
        self.assertEqual(ic["Duration"], duration)
        # self.assertEqual(ic["Blackout_Period"], black_period)
        # self.assertEqual(ic["Blackout_Event_Trigger"], black_trigger)
        self.assertEqual(camp_file["Events"][0]["Start_Day"], start_day)

        intervention = ic["Actual_IndividualIntervention_Config"]
        intervention_list = intervention["Intervention_List"]
        found_it = False
        for listed_intervention in intervention_list:
            if listed_intervention["class"] == intervention_class_name:
                found_it = True
                self.assertEqual(listed_intervention["TB_Drug_Name"], drug_name)
                self.assertEqual(listed_intervention["Latency_Multiplier"], latent_multiplier)
                self.assertEqual(listed_intervention["Active_Multiplier"], active_multiplier)
        self.assertTrue(found_it, msg=f"Expected to find {intervention_class_name} in list,"
                                      f" got {str(intervention_list)}")

    def test_new_intervention_as_file(self, intervention_class_name='TBHIVConfigurableTBdrug'):
        camp_filename = os.path.join(self.output, 'camp_tbhivtreat_as_file.json')
        super().new_intervention_as_file_test(treat, camp_filename, intervention_class_name, is_multi=True)


if __name__ == '__main__':
    unittest.main()

==> emodpy_tbhiv-1.2.0.dev2-py3-none-any.whl: tests/test_tbhivtreat.py <==
#!/usr/bin/env python
import unittest
import copy
import json
import os
import manifest
from intervention_test import TestIntervention

import emodpy_tbhiv.interventions.tbhiv_treat as treat
import emod_api.campaign as camp


class Testtbhivtreat(TestIntervention):
    """
    Test TBHIVConfigurableTBdrug intervention
    """
    def test_default(self):
        super().trigger_treatment_list_with_drug_name_test(treat.TBHIVDrugTreatment,
                                                           "TBHIVdrug", 'TBHIVConfigurableTBdrug',
                                                           'camp_tbhivtreat.json', is_multi=True)

    def test_all(self, intervention_class_name='TBHIVConfigurableTBdrug'):
        camp.set_schema( self.schema )
        treatment_list = ['Births']
        drug_name = 'TBHIVConfigurableTBdrug'
        latent_multiplier=0.9
        active_multiplier=0.9
        start_day=5
        duration=50
        property_restrictions_list = ["Risk: HIGH"]
        nodeIDs = []
        black_period = 10
        black_trigger = 'Blackout'
        event_name = 'TB Diagnosis Active Simple'
        intervention_class = "TBHIVDrugTreatment"
        event = treat.TBHIVDrugTreatment(camp, treatment_list, drug_name, latent_multiplier,
                                         active_multiplier, start_day, duration,
                                         property_restrictions_list, nodeIDs, black_period,
                                         black_trigger, event_name)

        camp.campaign_dict["Events"] = []
        camp.add(event)
        camp_filename = os.path.join(self.output, "camp_treat.json")
        manifest.delete_existing_file(camp_filename)
        camp.save(camp_filename)
        self.assertTrue(os.path.isfile(camp_filename))

        with open(camp_filename, 'r') as file:
            camp_file = json.load(file)
        ecc = camp_file["Events"][0]["Event_Coordinator_Config"]
        ic = ecc["Intervention_Config"]

        self.assertListEqual(ic["Property_Restrictions"], [property_restrictions.replace(" ", "") for
                                                           property_restrictions in property_restrictions_list])
        self.assertEqual(ic["Duration"], duration)
        # self.assertEqual(ic["Blackout_Period"], black_period)
        # self.assertEqual(ic["Blackout_Event_Trigger"], black_trigger)
        self.assertEqual(camp_file["Events"][0]["Start_Day"], start_day)

        intervention = ic["Actual_IndividualIntervention_Config"]
        intervention_list = intervention["Intervention_List"]
        found_it = False
        for listed_intervention in intervention_list:
            if listed_intervention["class"] == intervention_class_name:
                found_it = True
                self.assertEqual(listed_intervention["TB_Drug_Name"], drug_name)
                self.assertEqual(listed_intervention["Latency_Multiplier"], latent_multiplier)
                self.assertEqual(listed_intervention["Active_Multiplier"], active_multiplier)
        self.assertTrue(found_it, msg=f"Expected to find {intervention_class_name} in list,"
                                      f" got {str(intervention_list)}")

    def test_new_intervention_as_file(self, intervention_class_name='TBHIVConfigurableTBdrug'):
        camp_filename = os.path.join(self.output, 'camp_tbhivtreat_as_file.json')
        super().new_intervention_as_file_test(treat, camp_filename, intervention_class_name, is_multi=True)


if __name__ == '__main__':
    unittest.main()
